@@ -20,7 +20,7 @@ from .constants import DEBUG, INFO, WARNING, ERROR, CRITICAL, LOGGER_NAME
 __all__ = ['setLevel', 'debug', 'info', 'warning', 'error', 'DEBUG', 'INFO', 'WARNING', 'ERROR', 'CRITICAL', 'LOGGER_NAME']
 
 logger = logging.getLogger(LOGGER_NAME)
-logger.setLevel(logging.NOTSET)
 stdout_handler = logging.StreamHandler()
 stdout_handler.setFormatter(logging.Formatter('%(asctime)s [%(levelname)s] %(message)s'))
+stdout_handler.setLevel(logging.NOTSET)
 logger.addHandler(stdout_handler)
