@@ -12,7 +12,7 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-from typing import List, Tuple, Any, Optional
+from typing import List, Tuple, Optional
 from ..util.bytes import Bytes
 from .esv import ESV
 from .property import Property
@@ -39,6 +39,8 @@ class Message(ESV):
     SEOJ: int
     DEOJ: int
     properties: List[Property]
+    set_properties: List[Property]
+    get_properties: List[Property]
     from_addr: Optional[Tuple[str, int]]
     to_addr: Optional[Tuple[str, int]]
 
@@ -48,6 +50,8 @@ class Message(ESV):
         self.SEOJ = 0
         self.DEOJ = 0
         self.properties = []
+        self.set_properties = []
+        self.get_properties = []
         self.from_addr = None
         self.to_addr = None
 
@@ -60,17 +64,68 @@ class Message(ESV):
     def OPC(self) -> int:
         return len(self.properties)
 
-    def add_property(self, prop: Any) -> bool:
+    @property
+    def OPCSet(self) -> int:
+        return len(self.set_properties)
+
+    @property
+    def OPCGet(self) -> int:
+        return len(self.get_properties)
+
+    @property
+    def all_properties(self) -> List[Property]:
+        return self.properties + self.set_properties + self.get_properties
+
+    def add_property(self, prop: Property) -> bool:
         if not isinstance(prop, Property):
             return False
         self.properties.append(prop)
         return True
 
-    def is_response(self, msg):
+    def add_set_property(self, prop: Property) -> bool:
+        if not isinstance(prop, Property):
+            return False
+        self.set_properties.append(prop)
+        return True
+
+    def add_get_property(self, prop: Property) -> bool:
+        if not isinstance(prop, Property):
+            return False
+        self.get_properties.append(prop)
+        return True
+
+    def is_response_message(self, msg):
         if self.TID != msg.TID:
             return False
         return True
 
+    def __parse_property_bytes(self, msg_bytes, offset) -> Tuple[int, List[Property]]:
+        # Propety data
+        properties = []
+        opc = msg_bytes[offset]
+        offset += 1
+        for n in range(opc):
+            if len(msg_bytes) < (offset + 1):
+                raise Message.ParserError()
+            prop = Property()
+            prop.code = msg_bytes[offset]
+            offset += 1
+            pdc = msg_bytes[offset]
+            offset += 1
+            if len(msg_bytes) < (offset + pdc):
+                raise Message.ParserError()
+            prop.data = msg_bytes[offset:(offset + pdc)]
+            properties.append(prop)
+            offset += pdc
+        return offset, properties
+
+    def __is_read_write_message(self) -> bool:
+        if self.is_write_read_request():
+            return True
+        if self.is_write_read_response():
+            return True
+        return False
+
     def parse_bytes(self, msg_bytes) -> bool:
         # Frame heade
         if len(msg_bytes) < Message.FORMAT1_HEADER_SIZE:
@@ -87,27 +142,24 @@ class Message(ESV):
         self.ESV = msg_bytes[10]
 
         # Propety data
-        opc = msg_bytes[11]
-        offset = 12
-        for n in range(opc):
-            if len(msg_bytes) < (offset + 1):
-                raise Message.ParserError()
-            prop = Property()
-            prop.code = msg_bytes[offset]
-            offset += 1
-            pdc = msg_bytes[offset]
-            offset += 1
-            if len(msg_bytes) < (offset + pdc):
-                raise Message.ParserError()
-            prop.data = msg_bytes[offset:(offset + pdc)]
-            self.properties.append(prop)
-            offset += pdc
+        if self.__is_read_write_message():
+            offset, self.set_properties = self.__parse_property_bytes(msg_bytes, 11)
+            _, self.get_properties = self.__parse_property_bytes(msg_bytes, offset)
+        else:
+            _, self.properties = self.__parse_property_bytes(msg_bytes, 11)
 
         return True
 
     def parse_hexstring(self, hes_string: str) -> bool:
         return self.parse_bytes(Bytes.from_string(hes_string))
 
+    def __append_property_bytes(self, msg_bytes, properties) -> bytes:
+        msg_bytes.append(len(properties))
+        for prop in properties:
+            msg_bytes.append(prop.code)
+            msg_bytes.append(len(prop.data))
+            msg_bytes.extend(prop.data)
+
     def to_bytes(self) -> bytes:
         msg_bytes = bytearray([Message.EHD1_ECHONET, Message.EHD2_FORMAT1])
         msg_bytes.extend(Bytes.from_int(self.TID, 2))
@@ -115,11 +167,11 @@ class Message(ESV):
         msg_bytes.extend(Bytes.from_int(self.DEOJ, 3))
         msg_bytes.append(self.ESV)
 
-        msg_bytes.append(len(self.properties))
-        for prop in self.properties:
-            msg_bytes.append(prop.code)
-            msg_bytes.append(len(prop.data))
-            msg_bytes.extend(prop.data)
+        if self.__is_read_write_message():
+            self.__append_property_bytes(msg_bytes, self.set_properties)
+            self.__append_property_bytes(msg_bytes, self.get_properties)
+        else:
+            self.__append_property_bytes(msg_bytes, self.properties)
 
         return msg_bytes
 
